.. justbases documentation master file, created by
   sphinx-quickstart on Tue Feb 17 09:02:33 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Justbases
=========

Contents:

.. toctree::
   :maxdepth: 2

   intro
   usage
   justbases/modules
   tests/modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

